#
# spec file for package newsboat
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           newsboat
Version:        2.11.1
Release:        lp150.1.4
Summary:        RSS/Atom Feed Reader for Text Terminals
License:        MIT
Group:          Productivity/Networking/Web/Browsers
Url:            https://newsboat.org
Source:         https://newsboat.org/releases/%{version}/%{name}-%{version}.tar.xz
Source1:        https://newsboat.org/releases/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        https://newsboat.org/newsboat.pgp#/%{name}.keyring
# pbleser: introduce OPTFLAGS make variable, instead of hard-coded -ggdb
Patch1:         newsbeuter-makefile.patch
BuildRequires:  asciidoc
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  glibc-devel
BuildRequires:  libcurl-devel >= 7.18.0
BuildRequires:  libjson-c-devel >= 0.11
BuildRequires:  libopenssl-devel
BuildRequires:  libstdc++-devel
BuildRequires:  libstfl-devel >= 0.21
BuildRequires:  libxml2-devel
BuildRequires:  pkgconfig
BuildRequires:  sqlite3-devel >= 3.5
BuildRequires:  zlib-devel
Recommends:     %{name}-lang
Recommends:     web_browser
Provides:       newsbeuter = %{version}
Obsoletes:      newsbeuter <= 2.9

%description
Newsboat is an RSS/Atom feedreader. RSS and Atom are a number of
widely-used XML formats to transmit, publish and syndicate articles,
for example news or blog articles. Newsboat is designed to be used on
text terminals.

%lang_package

%prep
%setup -q
%patch1 -p1

%build
./config.sh

make %{?_smp_mflags} \
    	  OPTFLAGS="%{optflags}"

%install
%make_install prefix="%{_prefix}" docdir=%{_docdir}/%{name}

for l in zh; do
    rm -rf "%{buildroot}%{_datadir}/locale/${l}"
done

%find_lang %{name}

%files
%license LICENSE
%doc CHANGELOG.md README.md TODO
%{_bindir}/%{name}
%{_bindir}/podboat
%dir %{_docdir}/%{name}/examples
%{_docdir}/%{name}/examples/config
%{_docdir}/%{name}/docbook-xsl.css
%{_docdir}/%{name}/faq.html
%{_docdir}/%{name}/%{name}.html
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/podboat.1%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Sat Mar 31 2018 mvetter@suse.com
- Update to 2.11.1:
  * If built from the tarball, Newsboat 2.11 reported its
    version as 2.10.2.
* Mon Mar 26 2018 mvetter@suse.com
- Update to 2.11:
  * Podboat adds ".part" suffix of the files it currently downloads
  * Support for `CURL_CA_BUNDLE` environment variable
  * Fix unwanted logging to stdout on `--export-to-opml`
  * New command: `mark-all-above-as-read`
  * See https://github.com/newsboat/newsboat/releases/tag/r2.11
- Remove newsboat-2.10.2-json-c-size_t.patch: upstreamed
- Remove newsboat-nonexec-man.patch: upstreamed
- Rebase newsbeuter-makefile.patch
* Thu Jan 18 2018 mvetter@suse.com
- Add newsboat-2.10.2-json-c-size_t.patch: make work with json-c 0.13
* Fri Dec 29 2017 jengelh@inai.de
- Limit description to the openSUSE package context - replace
  by description from documentation.
* Thu Dec 28 2017 avindra@opensuse.org
- Update to version 2.10.2
  * Added
  - HTML anchors for all config commands in docs. You can now
    link to each command separately
  - Support for Inoreader
  - Slovak translation
  * Changed
  - Enqueue last audio enclosure
  - text-width doesn't apply if it's bigger than terminal width
  - Translations: German, Russian, Ukrainian
  * Removed
  - Build dependency on Perl
  - Test dependency on bc
  * Fixed
  - Do not create XDG data dir if not using XDG
  - When used with Newsblur, check on startup if cookie-cache
    exists or can be created, because integration doesn't work
    without cookies
  - Builds on AARCH64 and ARMHF
  - Only show an error message once when unknown option is
    supplied
  - License header used to say it's MIT/X Consortium License,
    whereas in reality it's a MIT License
  - Cross-compilation made possible by conditionally assigning
    to RANLIB and AR in Makefile
  - Cookies actually get persisted
  - CJK text is wrapped at correct code-point boundaries
  - Don't segfault if error-log points to non-existent file
  - Spanish translation
- add newsboat-nonexec-man.patch
  - this removes executable bits from the man pages
- rebase newsbeuter-makefile.patch
- remove newsbeuter-ncurses6.patch
  - fixed upstream in 317451791b950d7a48b7837995e45efb17ac6b15
- add dependency on asciidoc
  - man pages and docs are now packaged
* Thu Nov 16 2017 aavindraa@gmail.com
- rename package to newsboat
- neutralize description
- lint .spec file
- rebase newsbeuter-makefile.patch
- rebase newsbeuter-ncurses6.patch
- drop reproducible.patch
  * upstreamed in 8cf8bd40b449aa5f183f274df490d61e785ea4a6
* Mon May 22 2017 bwiedemann@suse.com
- Add reproducible.patch to sort input files to make build fully reproducible
* Tue Oct 13 2015 zaitor@opensuse.org
- Add newsbeuter-ncurses6.patch: Fix build with ncurses 6. Patch
  taken from Fedora. Apply only for openSUSE newer than 13.2.
* Thu Mar  5 2015 p.drouand@gmail.com
- Update to version 2.9
  * Fix custom keybindings in tag and filter selection dialogs (fixes #78).
  * Fix incorrect reloading of tags after editing the urls file.
  * Catch an exception that might be thrown by the "killfile" function.
  * Don't override feed titles for hidden feeds.
  * Fix dumpconfig.
  * Add support for FeedHQ (feedhq.org).
  * Fix missing variable in log output (fixes #124).
  * Fix type of configuration variables to path where appropriate (fixes #125).
  * Update to Brazilian Portuguese translation (fixes #126).
  * Fix crash when GUID is lost (fixes #127).
  * Fix dependency check (fixes #132).
  * Fix segfault in jump_to_next_unread_item (fixes #133).
  * Change code base to C++11.
  * Don't render inline images (fixes #154).
  * Fixed bug where feeds would appear empty due to variable shadowing issue.
- Remove merged patches
  * newsbeuter-ncurses.patch
  * newsbeuter-gcc47.patch
- Use download Url as source
- Remove obsolete conditional macros
- Split out translation files
- Remove depreciated/obsolete AUTHORS and %%clean sections
- Add libjson-c-devel build require; new upstream dependency
- Cleanup requirements list
* Sun Mar 25 2012 mrdocs@opensuse.org
  run -osc service localrun format_spec_file to fix copyright
* Wed Mar 21 2012 dimstar@opensuse.org
- Add newsbeuter-gcc47.patch: Fix build with gcc 4.7.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Feb  2 2011 pascal.bleser@opensuse.org
- update to 2.4:
  * support for query feeds in combination with Google Reader was added
  * it is now possible to configure proxy authentication methods
  * a quiet startup mode was added
  * overall memory usage was reduced by loading data from the cache only on
    demand
  * Bloglines support was removed
  * XDG Base Directory support was added
  * an authentication bug related to Google Reader was fixed
  * support for HTTP cookies was added
  * many small issues were fixed
* Thu Jun 24 2010 pascal.bleser@opensuse.org
- update to 2.3:
  * a number of miscellaneous bugs has been fixed, most notably the
    Google Reader authentication issue that came up when Google Reader
    changed its authentication scheme
- built against libstfl 0.21 (statically)
* Sun Mar 14 2010 pascal.bleser@opensuse.org
- update to 2.2:
  * support for Google Reader was added
  * a great number of bugs were fixed
  * the killfile functionality was improved
  * article highlighting in the article list based on article content
    was added
  * a "hard quit" keybinding was added
  * an HTML table renderer was added
* Wed Dec 16 2009 mrueckert@suse.de
- just recommend lynx
* Wed Dec  9 2009 pascal.bleser@opensuse.org
- update to 2.1:
  * add support for 256 color terminal
  * the first article is now selected upon entering the article
    list
  * the selection is moved to the next feed when a feed is marked
    as read in the feed list
  * HTML rendering has been improved
  * add support for SOCKS proxies
  * add a new notification type, "notify-beep"
  * fixes various bugs
* Mon Apr 20 2009 pascal.bleser@opensuse.org
- update to 2.0
* Sun Aug 31 2008 guru@unixtech.be
- update to 1.1:
  * support for wrapping long header lines and links in the article
    view was added
  * a security issue where opening specially crafted URLs of articles
    could lead to execution of shell commands was fixed
* Wed Aug 20 2008 guru@unixtech.be
- new package
